/*
 *  libprefixdb
 *  Copyright (C) 2002  Hongli Lai <h.lai@chello.nl>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


PrefixDB *
pdbInit (char *domain_name_version,
         char *prefix, char *bin, char *share,
         char *etc,    char *lib, char *libexec)
{
        PrefixDB *db;

        if (!domain_name_version)
                return NULL;

        db = calloc (sizeof (PrefixDB), 1);
        if (!db)
            {
                fprintf (stderr, "*ERROR*: pdbInit: unable to allocate %d "
                         "bytes of memory.\n", sizeof (PrefixDB));
                return NULL;
            }

        db->domain_name_version  = safe_strdup (domain_name_version);
        db->dbfile = calloc (1, PATH_MAX + 1);
        if (!db->dbfile)
            {
                fprintf (stderr, "*ERROR*: prefixdb: unable to "
                         "allocate %d bytes of memory!\n", PATH_MAX + 1);
                return NULL;
            }
        snprintf (db->dbfile, PATH_MAX + 1, PACKAGEDIR "/%s/prefixes",
            domain_name_version);

        db->prefix  = safe_strdup (prefix);
        db->bin     = safe_strdup (bin);
        db->share   = safe_strdup (share);
        db->etc     = safe_strdup (etc);
        db->lib     = safe_strdup (lib);
        db->libexec = safe_strdup (libexec);

        /* Set default values */
        db->prefix_exists = 1;
        db->bin_exists = 1;
        db->share_exists = 1;
        db->etc_exists = 1;
        db->lib_exists = 1;
        db->libexec_exists = 1;

        /* Check for existance */
        db->prefix_exists = check_and_free (pdbGetPrefix (db));
        db->bin_exists = check_and_free (pdbGetBin (db));
        db->share_exists = check_and_free (pdbGetShare (db));
        db->etc_exists = check_and_free (pdbGetEtc (db));
        db->lib_exists = check_and_free (pdbGetLib (db));
        db->libexec_exists = check_and_free (pdbGetLibexec (db));

        return db;
}


void
pdbFree (PrefixDB *db)
{
        if (!db)
                return;

        safe_free (db->domain_name_version);

        safe_free (db->prefix);
        safe_free (db->bin);
        safe_free (db->share);
        safe_free (db->etc);
        safe_free (db->lib);
        safe_free (db->libexec);

        safe_free (db->dbfile);
        safe_free (db);
}
